@@ -13,7 +13,7 @@ After=syslog.target
 
 [Service]
 Type=simple
-ExecStart=$entrypoint --command listen --verbose $verbose --port $port --gpio $gpio --name $name
+ExecStart=$entrypoint --command listen --verbose $verbose --port $port
 SyslogIdentifier=$packagename
 StandardOutput=syslog
 StandardError=syslog
@@ -28,21 +28,15 @@ WantedBy=multi-user.target
 
 class LightSensorApp(App):
 
-    def do_add_argument(self, parser):
-        parser.add_argument('--gpio', metavar='gpio', required=False, type=int, help='the gpio number wired to the device')
-        parser.add_argument('--name', metavar='name', required=False, default='Motion Sensor', type=str, help='the name of the sensor')
-
-    def do_additional_listen_example_params(self):
-        return "--gpio 14"
 
     def do_process_command(self, command:str, port: int, verbose: bool, args) -> bool:
         if command == 'listen' and (args.gpio is not None):
-            print("running " + self.packagename + " on port " + str(port) + " (gpio " + str(args.gpio) + ")")
-            run_server(port, int(args.gpio), args.name, self.description)
+            print("running " + self.packagename + " on port " + str(port))
+            run_server(port, description=self.description)
             return True
-        elif args.command == 'register' and (args.gpio is not None):
-            print("register " + self.packagename + " on port " + str(port) + " (gpio " + str(args.gpio) + ") and starting it")
-            unit = UNIT_TEMPLATE.substitute(packagename=self.packagename, entrypoint=self.entrypoint, port=port, verbose=verbose, gpio=args.gpio, name=args.name)
+        elif args.command == 'register':
+            print("register " + self.packagename + " on port " + str(port) + " and starting it")
+            unit = UNIT_TEMPLATE.substitute(packagename=self.packagename, entrypoint=self.entrypoint, port=port, verbose=verbose)
             self.unit.register(port, unit)
             return True
         else:
